Integer i = 10;
Boolean b;
String args[];
const MyType args[];
const My_Type args[];
List<Integer> mylist;
List<List<Integer> > mylist;
myspace::InputStream iStream ;
MyType *t;
MyType **t;
const MyType &t;
if (argc > 0) { }
__mytype _i;
typedef _mytype __i;
